==> maverik-6.1.tar.gz: maverik-6.1/incl/mav_vrml97.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2001 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/

#ifndef _MAV_VRML97_INCLUDE
#define _MAV_VRML97_INCLUDE

#ifdef __cplusplus
extern "C" {
#endif

/* Routine to define a composite from a VRML97 file */

int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m);



/* Options */

extern int mav_opt_VRML97CleanUp;
extern int mav_opt_VRML97HBBThreshold;



/* Module initialise */

char *mav_VRML97ModuleID(void);
int mav_VRML97ModuleInit(void);

#ifdef __cplusplus
}
#endif
#endif

==> maverik-6.2.tar.gz: maverik-6.2/incl/mav_vrml97.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2002 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/

#ifndef _MAV_VRML97_INCLUDE
#define _MAV_VRML97_INCLUDE

#ifdef MAVAPI
#undef MAVAPI
#endif
#if defined(WIN32) && !defined(__CYGWIN__) 
#ifdef LIBMAV_VRML97_EXPORTS
#define MAVAPI __declspec(dllexport) 
#else
#define MAVAPI __declspec(dllimport) 
#endif
#else
#define MAVAPI
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* Routine to define a composite from a VRML97 file */

MAVAPI int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m);



/* Options */

MAVAPI extern int mav_opt_VRML97CleanUp;
MAVAPI extern int mav_opt_VRML97HBBThreshold;



/* Module initialise */

MAVAPI char *mav_VRML97ModuleID(void);
MAVAPI int mav_VRML97ModuleInit(void);

#ifdef __cplusplus
}
#endif
#endif
